@@ -1,7 +1,21 @@
 /* melon.c -- a mailbox flag for X 
  *
  * Copyright(C) 2001-2002 Elisa Manara <e@entropika.net>
- * This code is released under the GPL License version 2 */
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */ 
 
 #include <gtk/gtk.h>
 #include <fcntl.h>
@@ -33,6 +47,7 @@ static void set_config_file(char *config_file_path);
 static void write_pid_file(void);
 static void parse_command_line (int argc, char **argv);
 static void extract_coordinates(char *arg_string);
+extern gint update_melon_position(gpointer data);
 
 char *set_melon_dir(void);
 void save_status(void);
@@ -108,10 +123,13 @@ int main (int argc, char *argv[])
 	set_style();
 
 	/* Create the main window */
-	window = gtk_window_new( GTK_WINDOW_POPUP );
+	window = gtk_window_new( GTK_WINDOW_TOPLEVEL );
 	gtk_window_set_title(GTK_WINDOW( window ), "melon");
 	w_data.window = window;
 
+	gtk_widget_set_events(window, GDK_BUTTON_MOTION_MASK | GDK_BUTTON_PRESS_MASK | 
+		GDK_BUTTON_RELEASE_MASK | GDK_EXPOSURE_MASK);
+
 	gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 		GTK_SIGNAL_FUNC (close_application), NULL);
 
@@ -171,6 +189,7 @@ int main (int argc, char *argv[])
 
 	gtk_timeout_add (cfg_data.interval, check_mbox, NULL);
 	gtk_timeout_add (250, melon_handle_signals, NULL);
+	gtk_timeout_add (500, update_melon_position, NULL);
 
 	gtk_main ();
 
@@ -191,20 +210,37 @@ gint buttons_handler(GtkWidget *widget, GdkEvent *event)
 {
 	GdkEventButton *event_button;
 
-	if (event->type == GDK_BUTTON_PRESS)
-	{
-		event_button = (GdkEventButton *) event;
-		/* press button 1 */
-		if (event_button->button == 1) {
-			active_mbox_menu(event_button);
-		/* press button 3 */
-		} else if (event_button->button == 3) {
+	event_button = (GdkEventButton *) event;
+
+	switch (event->type) {
+
+	case GDK_BUTTON_PRESS:
+		/* press button 3 - melon menu */
+		if (event_button->button == 3) {
 			pop_menu(event_button);
-			
+			return TRUE;
+
+		/* double click button 1 - mailbox menu */
+		} else if (event_button->button == 1) {
+			active_mbox_menu(event_button);
 			return TRUE;
 		}
-	} 
-	return FALSE;
+
+		return FALSE;
+		break;
+
+	/*
+	case GDK_2BUTTON_PRESS:
+		if (event_button->button == 1) {
+			active_mbox_menu(event_button);
+			return TRUE;
+		}
+		return FALSE;
+		break;
+	*/
+	default:
+		return FALSE;
+	}
 }
 
 int check_pixmaps(void)
@@ -313,10 +349,12 @@ void config_update (void)
 		if(cfg_data.mbox[i][0] == '\0')
 			break;
 
-		if(cfg_data.is_a_mbox[i])
+		if(cfg_data.is_a_mbox[i] == MELON_MBOX_TYPE)
 			fprintf(fp,"MBOX:%s\n", cfg_data.mbox[i]);
-		else
+		else if (cfg_data.is_a_mbox[i] == MELON_FILE_TYPE)
 			fprintf(fp,"FILE:%s\n", cfg_data.mbox[i]);
+		else if (cfg_data.is_a_mbox[i] == MELON_MDIR_TYPE)
+			fprintf(fp,"MDIR:%s\n", cfg_data.mbox[i]);
 
 	}
 	fclose(fp);
@@ -332,7 +370,7 @@ void load_config(void)
 			   "BEEP_MODE:", "BEEP_DEVICE:", "INTERVAL:", 
 			   "XPOSITION:", "YPOSITION:", "SAVE_STATUS:", 
 			   "MAILER:", "COLOR_STYLE:", "BGCOLOR:", "FGCOLOR:", 
-			   "ABGCOLOR:", "AFGCOLOR:", "MBOX:", "FILE:", NULL };
+			   "ABGCOLOR:", "AFGCOLOR:", "MBOX:", "FILE:", "MDIR:", NULL };
 
 	set_config_file(config_file);
 	/* set default configuration and initialize structs*/
@@ -413,11 +451,15 @@ void set_field(char *buf, char *field)
 			return;
 		} else if ((strcmp(field, "MBOX:")) == 0) {
 			st = cfg_data.mbox[mcount];
-			cfg_data.is_a_mbox[mcount] = 1;
+			cfg_data.is_a_mbox[mcount] = MELON_MBOX_TYPE;
 			mcount++;
 		} else if ((strcmp(field, "FILE:")) == 0) {
 			st = cfg_data.mbox[mcount];
-			cfg_data.is_a_mbox[mcount] = 0;
+			cfg_data.is_a_mbox[mcount] = MELON_FILE_TYPE;
+			mcount++;
+		} else if ((strcmp(field, "MDIR:")) == 0) {
+			st = cfg_data.mbox[mcount];
+			cfg_data.is_a_mbox[mcount] = MELON_MDIR_TYPE;
 			mcount++;
 		} else {
 			melon_error("Unknown keyword '%s' in config file\n", field);
@@ -430,7 +472,7 @@ void set_field(char *buf, char *field)
 void set_default_cfg (void)
 {
 	int i;
-	char *mbox;
+	/* char *mbox; */
 
 	set_melon_def_colors();
 
@@ -451,12 +493,14 @@ void set_default_cfg (void)
 		/* initialize active_mbox */
 		active_mbox[i][0] = '\0';
 		/* initialize is_a_mbox */
-		cfg_data.is_a_mbox[i] = 0;
+		cfg_data.is_a_mbox[i] = MELON_FILE_TYPE;
 	}
+	/*
 	if((mbox = getenv("MAIL"))) {
 		strncpy(cfg_data.mbox[0], mbox, MAX_PLEN);
-		cfg_data.is_a_mbox[0] = 1;
+		cfg_data.is_a_mbox[0] = MELON_MBOX_TYPE;
 	}
+	*/
 
 	cfg_data.mailer[0] = '\0';
 }
@@ -725,3 +769,4 @@ void extract_coordinates (char *arg_string)
 		strncpy(cfg_data.yposition, ypos, 16);
 	}
 }
+
